@@ -25,7 +25,6 @@
 #include "rygel-test-audio-item.h"
 #include <rygel-media-item.h>
 #include <rygel-media-object.h>
-#include <rygel-live-response.h>
 
 
 
@@ -35,24 +34,23 @@ enum  {
 };
 #define RYGEL_TEST_AUDIO_ITEM_TEST_MIMETYPE "audio/x-wav"
 static inline void _dynamic_set_is_live0 (GstElement* obj, gboolean value);
-static GstElement* rygel_test_audio_item_real_create_gst_source (RygelTestItem* base, GError** error);
+static GstElement* rygel_test_audio_item_real_create_stream_source (RygelMediaItem* base);
 static gpointer rygel_test_audio_item_parent_class = NULL;
 
 
 
-RygelTestAudioItem* rygel_test_audio_item_construct (GType object_type, const char* id, const char* parent_id, const char* title, RygelHTTPServer* http_server) {
-	RygelTestAudioItem* self;
+RygelTestAudioItem* rygel_test_audio_item_construct (GType object_type, const char* id, RygelMediaContainer* parent, const char* title) {
+	RygelTestAudioItem * self;
 	g_return_val_if_fail (id != NULL, NULL);
-	g_return_val_if_fail (parent_id != NULL, NULL);
+	g_return_val_if_fail (parent != NULL, NULL);
 	g_return_val_if_fail (title != NULL, NULL);
-	g_return_val_if_fail (http_server != NULL, NULL);
-	self = (RygelTestAudioItem*) rygel_test_item_construct (object_type, id, parent_id, title, RYGEL_TEST_AUDIO_ITEM_TEST_MIMETYPE, RYGEL_MEDIA_ITEM_AUDIO_CLASS, http_server);
+	self = (RygelTestAudioItem*) rygel_test_item_construct (object_type, id, parent, title, RYGEL_TEST_AUDIO_ITEM_TEST_MIMETYPE, RYGEL_MEDIA_ITEM_AUDIO_CLASS);
 	return self;
 }
 
 
-RygelTestAudioItem* rygel_test_audio_item_new (const char* id, const char* parent_id, const char* title, RygelHTTPServer* http_server) {
-	return rygel_test_audio_item_construct (RYGEL_TYPE_TEST_AUDIO_ITEM, id, parent_id, title, http_server);
+RygelTestAudioItem* rygel_test_audio_item_new (const char* id, RygelMediaContainer* parent, const char* title) {
+	return rygel_test_audio_item_construct (RYGEL_TYPE_TEST_AUDIO_ITEM, id, parent, title);
 }
 
 
@@ -61,24 +59,22 @@ static inline void _dynamic_set_is_live0 (GstElement* obj, gboolean value) {
 }
 
 
-static GstElement* rygel_test_audio_item_real_create_gst_source (RygelTestItem* base, GError** error) {
+static GstElement* rygel_test_audio_item_real_create_stream_source (RygelMediaItem* base) {
 	RygelTestAudioItem * self;
-	GError * inner_error;
 	GstBin* bin;
 	GstElement* src;
 	GstElement* encoder;
 	gboolean _tmp0;
+	GstElement* _tmp3;
 	GstElement* _tmp2;
-	GstElement* _tmp1;
 	GstPad* pad;
+	char* _tmp5;
 	char* _tmp4;
-	char* _tmp3;
-	GstGhostPad* _tmp5;
+	GstGhostPad* _tmp6;
 	GstGhostPad* ghost;
-	GstPad* _tmp6;
-	GstElement* _tmp7;
+	GstPad* _tmp7;
+	GstElement* _tmp8;
 	self = (RygelTestAudioItem*) base;
-	inner_error = NULL;
 	bin = (GstBin*) gst_bin_new (((RygelMediaObject*) self)->title);
 	src = gst_element_factory_make ("audiotestsrc", NULL);
 	encoder = gst_element_factory_make ("wavenc", NULL);
@@ -89,39 +85,35 @@ static GstElement* rygel_test_audio_item_real_create_gst_source (RygelTestItem*
 		_tmp0 = encoder == NULL;
 	}
 	if (_tmp0) {
-		inner_error = g_error_new_literal (RYGEL_LIVE_RESPONSE_ERROR, RYGEL_LIVE_RESPONSE_ERROR_MISSING_PLUGIN, "Required plugin missing");
-		if (inner_error != NULL) {
-			g_propagate_error (error, inner_error);
-			(bin == NULL) ? NULL : (bin = (gst_object_unref (bin), NULL));
-			(src == NULL) ? NULL : (src = (gst_object_unref (src), NULL));
-			(encoder == NULL) ? NULL : (encoder = (gst_object_unref (encoder), NULL));
-			return NULL;
-		}
+		GstElement* _tmp1;
+		g_warning ("rygel-test-audio-item.vala:53: Required plugin missing");
+		_tmp1 = NULL;
+		return (_tmp1 = NULL, (bin == NULL) ? NULL : (bin = (gst_object_unref (bin), NULL)), (src == NULL) ? NULL : (src = (gst_object_unref (src), NULL)), (encoder == NULL) ? NULL : (encoder = (gst_object_unref (encoder), NULL)), _tmp1);
 	}
 	/* Tell the source to behave like a live source*/
 	_dynamic_set_is_live0 (src, TRUE);
 	/* Add elements to our source bin*/
+	_tmp3 = NULL;
 	_tmp2 = NULL;
-	_tmp1 = NULL;
-	gst_bin_add_many (bin, (_tmp1 = src, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)), (_tmp2 = encoder, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)), NULL);
+	gst_bin_add_many (bin, (_tmp2 = src, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)), (_tmp3 = encoder, (_tmp3 == NULL) ? NULL : gst_object_ref (_tmp3)), NULL);
 	/* Link them*/
 	gst_element_link (src, encoder);
 	/* Now add the encoder's src pad to the bin*/
 	pad = gst_element_get_static_pad (encoder, "src");
-	_tmp4 = NULL;
-	_tmp3 = NULL;
 	_tmp5 = NULL;
-	ghost = (_tmp5 = (GstGhostPad*) gst_ghost_pad_new (_tmp4 = g_strconcat (_tmp3 = g_strconcat (gst_object_get_name ((GstObject*) bin), ".", NULL), gst_object_get_name ((GstObject*) pad), NULL), pad), _tmp4 = (g_free (_tmp4), NULL), _tmp3 = (g_free (_tmp3), NULL), _tmp5);
+	_tmp4 = NULL;
 	_tmp6 = NULL;
-	gst_element_add_pad ((GstElement*) bin, (_tmp6 = (GstPad*) ghost, (_tmp6 == NULL) ? NULL : gst_object_ref (_tmp6)));
+	ghost = (_tmp6 = (GstGhostPad*) gst_ghost_pad_new (_tmp5 = g_strconcat (_tmp4 = g_strconcat (gst_object_get_name ((GstObject*) bin), ".", NULL), gst_object_get_name ((GstObject*) pad), NULL), pad), _tmp5 = (g_free (_tmp5), NULL), _tmp4 = (g_free (_tmp4), NULL), _tmp6);
 	_tmp7 = NULL;
-	return (_tmp7 = (GstElement*) bin, (src == NULL) ? NULL : (src = (gst_object_unref (src), NULL)), (encoder == NULL) ? NULL : (encoder = (gst_object_unref (encoder), NULL)), (pad == NULL) ? NULL : (pad = (gst_object_unref (pad), NULL)), (ghost == NULL) ? NULL : (ghost = (gst_object_unref (ghost), NULL)), _tmp7);
+	gst_element_add_pad ((GstElement*) bin, (_tmp7 = (GstPad*) ghost, (_tmp7 == NULL) ? NULL : gst_object_ref (_tmp7)));
+	_tmp8 = NULL;
+	return (_tmp8 = (GstElement*) bin, (src == NULL) ? NULL : (src = (gst_object_unref (src), NULL)), (encoder == NULL) ? NULL : (encoder = (gst_object_unref (encoder), NULL)), (pad == NULL) ? NULL : (pad = (gst_object_unref (pad), NULL)), (ghost == NULL) ? NULL : (ghost = (gst_object_unref (ghost), NULL)), _tmp8);
 }
 
 
 static void rygel_test_audio_item_class_init (RygelTestAudioItemClass * klass) {
 	rygel_test_audio_item_parent_class = g_type_class_peek_parent (klass);
-	RYGEL_TEST_ITEM_CLASS (klass)->create_gst_source = rygel_test_audio_item_real_create_gst_source;
+	RYGEL_MEDIA_ITEM_CLASS (klass)->create_stream_source = rygel_test_audio_item_real_create_stream_source;
 }
 
 
