@@ -22,7 +22,7 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <rygel-connection-manager.h>
+#include "rygel-connection-manager.h"
 
 
 
