@@ -21,7 +21,7 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <rygel-http-response.h>
+#include "rygel-http-response.h"
 
 
 
@@ -36,10 +36,14 @@ enum  {
 	RYGEL_HTTP_RESPONSE_SERVER
 };
 static void _rygel_http_response_on_request_aborted_soup_server_request_aborted (SoupServer* _sender, SoupMessage* msg, SoupClientContext* client, gpointer self);
+static void _rygel_http_response_on_cancelled_g_cancellable_cancelled (GCancellable* _sender, gpointer self);
+static void rygel_http_response_real_run (RygelHTTPResponse* self, GCancellable* cancellable);
+static void rygel_http_response_on_cancelled (RygelHTTPResponse* self, GCancellable* cancellable);
 static void rygel_http_response_on_request_aborted (RygelHTTPResponse* self, SoupServer* server, SoupMessage* msg, SoupClientContext* client);
 static void rygel_http_response_real_end (RygelHTTPResponse* self, gboolean aborted, guint status);
 static void rygel_http_response_set_server (RygelHTTPResponse* self, SoupServer* value);
 static gpointer rygel_http_response_parent_class = NULL;
+static RygelStateMachineIface* rygel_http_response_rygel_state_machine_parent_iface = NULL;
 static void rygel_http_response_finalize (GObject* obj);
 struct _RygelSeekPrivate {
 	GstFormat _format;
@@ -79,12 +83,12 @@ RygelHTTPResponse* rygel_http_response_construct (GType object_type, SoupServer*
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->msg = (_tmp1 = (_tmp0 = msg, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->msg == NULL) ? NULL : (self->msg = (g_object_unref (self->msg), NULL)), _tmp1);
-	soup_server_pause_message (server, self->msg);
 	if (partial) {
 		soup_message_set_status (self->msg, (guint) SOUP_STATUS_PARTIAL_CONTENT);
 	} else {
 		soup_message_set_status (self->msg, (guint) SOUP_STATUS_OK);
 	}
+	soup_message_body_set_accumulate (self->msg->response_body, FALSE);
 	g_signal_connect_object (self->priv->_server, "request-aborted", (GCallback) _rygel_http_response_on_request_aborted_soup_server_request_aborted, self, 0);
 	return self;
 }
@@ -95,6 +99,36 @@ RygelHTTPResponse* rygel_http_response_new (SoupServer* server, SoupMessage* msg
 }
 
 
+static void _rygel_http_response_on_cancelled_g_cancellable_cancelled (GCancellable* _sender, gpointer self) {
+	rygel_http_response_on_cancelled (self, _sender);
+}
+
+
+static void rygel_http_response_real_run (RygelHTTPResponse* self, GCancellable* cancellable) {
+	g_return_if_fail (self != NULL);
+	if (cancellable != NULL) {
+		GCancellable* _tmp1;
+		GCancellable* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->cancellable = (_tmp1 = (_tmp0 = cancellable, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->cancellable == NULL) ? NULL : (self->cancellable = (g_object_unref (self->cancellable), NULL)), _tmp1);
+		g_signal_connect_object (cancellable, "cancelled", (GCallback) _rygel_http_response_on_cancelled_g_cancellable_cancelled, self, 0);
+	}
+}
+
+
+void rygel_http_response_run (RygelHTTPResponse* self, GCancellable* cancellable) {
+	RYGEL_HTTP_RESPONSE_GET_CLASS (self)->run (self, cancellable);
+}
+
+
+static void rygel_http_response_on_cancelled (RygelHTTPResponse* self, GCancellable* cancellable) {
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (cancellable != NULL);
+	rygel_http_response_end (self, TRUE, (guint) SOUP_STATUS_CANCELLED);
+}
+
+
 static void rygel_http_response_on_request_aborted (RygelHTTPResponse* self, SoupServer* server, SoupMessage* msg, SoupClientContext* client) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (server != NULL);
@@ -107,13 +141,6 @@ static void rygel_http_response_on_request_aborted (RygelHTTPResponse* self, Sou
 }
 
 
-void rygel_http_response_set_mime_type (RygelHTTPResponse* self, const char* mime_type) {
-	g_return_if_fail (self != NULL);
-	g_return_if_fail (mime_type != NULL);
-	soup_message_headers_append (self->msg->response_headers, "Content-Type", mime_type);
-}
-
-
 void rygel_http_response_push_data (RygelHTTPResponse* self, void* data, gsize length) {
 	g_return_if_fail (self != NULL);
 	soup_message_body_append (self->msg->response_body, SOUP_MEMORY_COPY, data, length);
@@ -126,7 +153,7 @@ static void rygel_http_response_real_end (RygelHTTPResponse* self, gboolean abor
 	if (status != SOUP_STATUS_NONE) {
 		soup_message_set_status (self->msg, status);
 	}
-	g_signal_emit_by_name (self, "ended");
+	g_signal_emit_by_name ((RygelStateMachine*) self, "completed");
 }
 
 
@@ -187,9 +214,15 @@ static void rygel_http_response_class_init (RygelHTTPResponseClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = rygel_http_response_get_property;
 	G_OBJECT_CLASS (klass)->set_property = rygel_http_response_set_property;
 	G_OBJECT_CLASS (klass)->finalize = rygel_http_response_finalize;
+	RYGEL_HTTP_RESPONSE_CLASS (klass)->run = rygel_http_response_real_run;
 	RYGEL_HTTP_RESPONSE_CLASS (klass)->end = rygel_http_response_real_end;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), RYGEL_HTTP_RESPONSE_SERVER, g_param_spec_object ("server", "server", "server", SOUP_TYPE_SERVER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_signal_new ("ended", RYGEL_TYPE_HTTP_RESPONSE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+}
+
+
+static void rygel_http_response_rygel_state_machine_interface_init (RygelStateMachineIface * iface) {
+	rygel_http_response_rygel_state_machine_parent_iface = g_type_interface_peek_parent (iface);
+	iface->run = rygel_http_response_run;
 }
 
 
@@ -203,6 +236,7 @@ static void rygel_http_response_finalize (GObject* obj) {
 	self = RYGEL_HTTP_RESPONSE (obj);
 	(self->priv->_server == NULL) ? NULL : (self->priv->_server = (g_object_unref (self->priv->_server), NULL));
 	(self->msg == NULL) ? NULL : (self->msg = (g_object_unref (self->msg), NULL));
+	(self->cancellable == NULL) ? NULL : (self->cancellable = (g_object_unref (self->cancellable), NULL));
 	G_OBJECT_CLASS (rygel_http_response_parent_class)->finalize (obj);
 }
 
@@ -211,7 +245,9 @@ GType rygel_http_response_get_type (void) {
 	static GType rygel_http_response_type_id = 0;
 	if (rygel_http_response_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (RygelHTTPResponseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) rygel_http_response_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (RygelHTTPResponse), 0, (GInstanceInitFunc) rygel_http_response_instance_init, NULL };
-		rygel_http_response_type_id = g_type_register_static (G_TYPE_OBJECT, "RygelHTTPResponse", &g_define_type_info, 0);
+		static const GInterfaceInfo rygel_state_machine_info = { (GInterfaceInitFunc) rygel_http_response_rygel_state_machine_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		rygel_http_response_type_id = g_type_register_static (G_TYPE_OBJECT, "RygelHTTPResponse", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+		g_type_add_interface_static (rygel_http_response_type_id, RYGEL_TYPE_STATE_MACHINE, &rygel_state_machine_info);
 	}
 	return rygel_http_response_type_id;
 }
