@@ -20,7 +20,7 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <rygel-media-receiver-registrar.h>
+#include "rygel-media-receiver-registrar.h"
 #include <stdlib.h>
 #include <string.h>
 
