@@ -29,13 +29,14 @@
 #include <string.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
+#include <cstuff.h>
 #include <gee/collection.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
-#include <rygel-icon-info.h>
-#include <rygel-resource-info.h>
 #include <stdio.h>
 #include <gio/gio.h>
+#include "rygel-icon-info.h"
+#include "rygel-resource-info.h"
 #include <gobject/gvaluecollector.h>
 
 
@@ -86,7 +87,7 @@ RygelMediaServerFactory* rygel_media_server_factory_construct (GType object_type
 	_tmp2 = rygel_media_server_factory_create_upnp_context (self, &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
-		return NULL;
+		return;
 	}
 	/* Set up GUPnP context */
 	_tmp3 = NULL;
@@ -160,13 +161,13 @@ static xmlDoc* rygel_media_server_factory_create_desc (RygelMediaServerFactory*
 		_tmp0 = NULL;
 		_tmp2 = (_tmp1 = gconf_client_get_bool (self->priv->gconf, _tmp0 = g_strconcat (gconf_path, "enable-xbox", NULL), &inner_error), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 		if (inner_error != NULL) {
-			goto __catch0_g_error;
-			goto __finally0;
+			goto __catch11_g_error;
+			goto __finally11;
 		}
 		enable_xbox = _tmp2;
 	}
-	goto __finally0;
-	__catch0_g_error:
+	goto __finally11;
+	__catch11_g_error:
 	{
 		GError * error;
 		error = inner_error;
@@ -176,7 +177,7 @@ static xmlDoc* rygel_media_server_factory_create_desc (RygelMediaServerFactory*
 			(error == NULL) ? NULL : (error = (g_error_free (error), NULL));
 		}
 	}
-	__finally0:
+	__finally11:
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return NULL;
@@ -234,15 +235,15 @@ static GUPnPContext* rygel_media_server_factory_create_upnp_context (RygelMediaS
 		const char* _tmp1;
 		_tmp0 = gconf_client_get_string (self->priv->gconf, RYGEL_MEDIA_SERVER_FACTORY_ROOT_GCONF_PATH "host-ip", &inner_error);
 		if (inner_error != NULL) {
-			goto __catch1_g_error;
-			goto __finally1;
+			goto __catch12_g_error;
+			goto __finally12;
 		}
 		_tmp2 = NULL;
 		_tmp1 = NULL;
 		host_ip = (_tmp2 = (_tmp1 = _tmp0, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), host_ip = (g_free (host_ip), NULL), _tmp2);
 	}
-	goto __finally1;
-	__catch1_g_error:
+	goto __finally12;
+	__catch12_g_error:
 	{
 		GError * error;
 		error = inner_error;
@@ -255,7 +256,7 @@ static GUPnPContext* rygel_media_server_factory_create_upnp_context (RygelMediaS
 			(error == NULL) ? NULL : (error = (g_error_free (error), NULL));
 		}
 	}
-	__finally1:
+	__finally12:
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		host_ip = (g_free (host_ip), NULL);
@@ -266,13 +267,13 @@ static GUPnPContext* rygel_media_server_factory_create_upnp_context (RygelMediaS
 		gint _tmp4;
 		_tmp4 = gconf_client_get_int (self->priv->gconf, RYGEL_MEDIA_SERVER_FACTORY_ROOT_GCONF_PATH "port", &inner_error);
 		if (inner_error != NULL) {
-			goto __catch2_g_error;
-			goto __finally2;
+			goto __catch13_g_error;
+			goto __finally13;
 		}
 		port = _tmp4;
 	}
-	goto __finally2;
-	__catch2_g_error:
+	goto __finally13;
+	__catch13_g_error:
 	{
 		GError * error;
 		error = inner_error;
@@ -283,7 +284,7 @@ static GUPnPContext* rygel_media_server_factory_create_upnp_context (RygelMediaS
 			(error == NULL) ? NULL : (error = (g_error_free (error), NULL));
 		}
 	}
-	__finally2:
+	__finally13:
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		host_ip = (g_free (host_ip), NULL);
@@ -316,15 +317,15 @@ static char* rygel_media_server_factory_get_str_from_gconf (RygelMediaServerFact
 		const char* _tmp1;
 		_tmp0 = gconf_client_get_string (self->priv->gconf, key, &inner_error);
 		if (inner_error != NULL) {
-			goto __catch3_g_error;
-			goto __finally3;
+			goto __catch14_g_error;
+			goto __finally14;
 		}
 		_tmp2 = NULL;
 		_tmp1 = NULL;
 		str = (_tmp2 = (_tmp1 = _tmp0, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), str = (g_free (str), NULL), _tmp2);
 	}
-	goto __finally3;
-	__catch3_g_error:
+	goto __finally14;
+	__catch14_g_error:
 	{
 		GError * error;
 		error = inner_error;
@@ -339,7 +340,7 @@ static char* rygel_media_server_factory_get_str_from_gconf (RygelMediaServerFact
 			(error == NULL) ? NULL : (error = (g_error_free (error), NULL));
 		}
 	}
-	__finally3:
+	__finally14:
 	if (inner_error != NULL) {
 		str = (g_free (str), NULL);
 		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
@@ -355,12 +356,12 @@ static char* rygel_media_server_factory_get_str_from_gconf (RygelMediaServerFact
 		{
 			gconf_client_set_string (self->priv->gconf, key, default_value, &inner_error);
 			if (inner_error != NULL) {
-				goto __catch4_g_error;
-				goto __finally4;
+				goto __catch15_g_error;
+				goto __finally15;
 			}
 		}
-		goto __finally4;
-		__catch4_g_error:
+		goto __finally15;
+		__catch15_g_error:
 		{
 			GError * error;
 			error = inner_error;
@@ -370,7 +371,7 @@ static char* rygel_media_server_factory_get_str_from_gconf (RygelMediaServerFact
 				(error == NULL) ? NULL : (error = (g_error_free (error), NULL));
 			}
 		}
-		__finally4:
+		__finally15:
 		if (inner_error != NULL) {
 			str = (g_free (str), NULL);
 			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
