@@ -21,7 +21,7 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <rygel-resource-info.h>
+#include "rygel-resource-info.h"
 #include <gobject/gvaluecollector.h>
 
 
